module control(reset, sclk, ir, c, z, select);
input	reset, sclk, c, z;
input 	[7:0] ir;
output 	[7:0] select;
reg 	[1:0] ss;
reg 	[7:0] select;

// Control signal 	
// select[7]: PC load
// select[6]: ACC latch
// select[5]: ALU, c,z latch 
// select[4]: PC count up or load enable
// select[3]: IR latch  
// select[2]: memory read/write 
// select[1]: ACC data from ALU:1 or memory:0
// select[0]: address select PC:1 or IR_L:0

always @(posedge sclk or posedge reset) begin
	if (reset) ss<=2'b00;
	else case (ss)	
		2'b00: 			begin select<=8'b00001001; ss<=2'b01; end	// fetch cycle 1
		2'b01: 			begin select<=8'b00010000; ss<=2'b10; end	// fetch cycle 2
		2'b10: 														// exec cycle 1
			casex (ir[7:5])
				3'b0XX:	begin select<=8'b00100000; ss<=2'b11; end	// ADD,SUB,NAND,SHIFT
				3'b100: begin select<=8'b01000000; ss<=2'b00; end	// LD
				3'b101: begin select<=8'b00100000; ss<=2'b11; end	// ST
				3'b110: begin										// JPC
				 if(~c) begin select<=8'b00000000; ss<=2'b00; end	//	 C=0, nop
				 if(c)  begin select<=8'b10000000; ss<=2'b00; end	//   C=1, jump
				 end
				3'b111: begin										// JPNZ
				 if(~z) begin select<=8'b10000000; ss<=2'b00; end	//   Z=0, jump
				 if(z) 	begin select<=8'b00000000; ss<=2'b00; end	//   z=1, nop
			 	 end
			endcase
		2'b11: 														// exec cycle 2
			casex (ir[7:5])
				3'b0XX:	begin select<=8'b01000010; ss<=2'b00; end	// ADD,SUB,NAND,SHIFT
				3'b101: begin select<=8'b00000110; ss<=2'b00; end	// ST
			endcase
	endcase
end

endmodule
